Crate rusoto_iotevents_data

Crate rusoto_iotevents_data 

AWS IoT Events monitors your equipment or device fleets for failures or changes in operation, and triggers actions when such events occur. AWS IoT Events Data API commands enable you to send inputs to detectors, list detectors, and view or update a detector's status.

If you’re using the service, you’re probably looking for IotEventsDataClient and IotEventsData.

Structs

BatchPutMessageErrorEntry

Contains information about the errors encountered.

BatchPutMessageRequest
BatchPutMessageResponse
BatchUpdateDetectorErrorEntry

Information about the error that occured when attempting to update a detector.

BatchUpdateDetectorRequest
BatchUpdateDetectorResponse
DescribeDetectorRequest
DescribeDetectorResponse
Detector

Information about the detector (instance).

DetectorState

Information about the current state of the detector instance.

DetectorStateDefinition

The new state, variable values, and timer settings of the detector (instance).

DetectorStateSummary

Information about the detector state.

DetectorSummary

Information about the detector (instance).

IotEventsDataClient
A client for the AWS IoT Events Data API.
ListDetectorsRequest
ListDetectorsResponse
Message

Information about a message.

Timer

The current state of a timer.

TimerDefinition

The new setting of a timer.

UpdateDetectorRequest

Information used to update the detector (instance).

Variable

The current state of the variable.

VariableDefinition

The new value of the variable.

Enums

BatchPutMessageError
Errors returned by BatchPutMessage
BatchUpdateDetectorError
Errors returned by BatchUpdateDetector
DescribeDetectorError
Errors returned by DescribeDetector
ListDetectorsError
Errors returned by ListDetectors

Traits

IotEventsData
Trait representing the capabilities of the AWS IoT Events Data API. AWS IoT Events Data clients implement this trait.