AWS IoT Events monitors your equipment or device fleets for failures or changes in operation, and triggers actions when such events occur. AWS IoT Events Data API commands enable you to send inputs to detectors, list detectors, and view or update a detector's status.
If you’re using the service, you’re probably looking for IotEventsDataClient and IotEventsData.
Structs
- Batch
PutMessage Error Entry Contains information about the errors encountered.
- Batch
PutMessage Request - Batch
PutMessage Response - Batch
Update Detector Error Entry Information about the error that occured when attempting to update a detector.
- Batch
Update Detector Request - Batch
Update Detector Response - Describe
Detector Request - Describe
Detector Response - Detector
Information about the detector (instance).
- Detector
State Information about the current state of the detector instance.
- Detector
State Definition The new state, variable values, and timer settings of the detector (instance).
- Detector
State Summary Information about the detector state.
- Detector
Summary Information about the detector (instance).
- IotEvents
Data Client - A client for the AWS IoT Events Data API.
- List
Detectors Request - List
Detectors Response - Message
Information about a message.
- Timer
The current state of a timer.
- Timer
Definition The new setting of a timer.
- Update
Detector Request Information used to update the detector (instance).
- Variable
The current state of the variable.
- Variable
Definition The new value of the variable.
Enums
- Batch
PutMessage Error - Errors returned by BatchPutMessage
- Batch
Update Detector Error - Errors returned by BatchUpdateDetector
- Describe
Detector Error - Errors returned by DescribeDetector
- List
Detectors Error - Errors returned by ListDetectors
Traits
- IotEvents
Data - Trait representing the capabilities of the AWS IoT Events Data API. AWS IoT Events Data clients implement this trait.